### Persefone.jl - a model of agricultural landscapes and ecosystems in Europe.
###
### Build the HTML documentation for Persefone using Documenter.jl
### https://documenter.juliadocs.org/stable/
### 

using Pkg

Pkg.activate("..")

push!(LOAD_PATH, "../src/")

using Documenter, Persefone

# build the online documentation
makedocs(sitename="Persefone.jl",
         modules = [Persefone],
         repo = Remotes.GitLab("git.idiv.de", "persefone", "persefone-model"),
         format = Documenter.HTML(prettyurls = false),
         warnonly = true, #XXX not recommended
         #warnonly = [:cross_references],
         pages = ["index.md",
                  "User guide" => [
                      "using.md",
                      "gui.md",
                      "config.md"],
                  "Scientific documentation" => [
                      "management.md",
                      "crop-models.md",
                      "skylark.md"],
                  "Developer guide" => [
                      "developing.md",
                      "adapting.md",
                      "architecture.md",
                      "gis.md",
                      "species-dsl.md",
                      "CHANGELOG.md"],
                  "Software API" => [
                      "simulation.md",
                      "io.md",
                      "nature.md",
                      #"energy.md",
                      "species.md",
                      "crops.md",
                      "farm.md"]
                  ])

# compile the handbook
#XXX change to LaTeX output for manual editing?
# or configure the title page https://github.com/JuliaDocs/Documenter.jl/blob/master/test/examples/src.cover_page/assets/titlepage.tex
# makedocs(format = Documenter.LaTeX(),
#          sitename="Persefone.jl",
#          authors="Daniel Vedder, Marco C. Matthies, Guy Pe'er",
#          modules = [Persefone],
#          repo = Remotes.GitLab("git.idiv.de", "persefone", "persefone-model"),
#          warnonly = true, #XXX not recommended
#          #warnonly = [:cross_references],
#          pages = ["index.md",
#                   "User guide" => [
#                       "using.md",
#                       "gui.md",
#                       "config.md"],
#                   "Scientific documentation" => [
#                       "management.md",
#                       "crop-models.md",
#                       "skylark.md"],
#                   "Developer guide" => [
#                       "developing.md",
#                       "adapting.md",
#                       "architecture.md",
#                       "gis.md",
#                       "species-dsl.md"],
#                   "Software API" => [
#                       "simulation.md",
#                       "io.md",
#                       "nature.md",
#                       "species.md",
#                       "crops.md",
#                       "farm.md"]
#                   ])
